@@ -11,6 +11,7 @@ static gboolean skip_tasklist = FALSE;
 static gboolean transparent = FALSE;
 static gboolean vertical = FALSE;
 static gint icon_size = WNCK_DEFAULT_MINI_ICON_SIZE;
+static gboolean enable_scroll = TRUE;
 
 static GOptionEntry entries[] = {
 	{"always-group", 'g', 0, G_OPTION_ARG_NONE, &always_group, "Always group windows", NULL},
@@ -21,6 +22,7 @@ static GOptionEntry entries[] = {
 	{"skip-tasklist", 's', 0, G_OPTION_ARG_NONE, &skip_tasklist, "Don't show window in tasklist", NULL},
 	{"vertical", 'v', 0, G_OPTION_ARG_NONE, &vertical, "Show in vertical mode", NULL},
 	{"transparent", 't', 0, G_OPTION_ARG_NONE, &transparent, "Enable Transparency", NULL},
+	{"disable-scroll", 'd', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &enable_scroll, "Disable scrolling", NULL},
 	{NULL }
 };
 
@@ -40,9 +42,11 @@ static void
 window_composited_changed (GtkWidget *widget,
                            gpointer   user_data)
 {
+  GdkScreen *screen;
   gboolean composited;
 
-  composited = gtk_widget_is_composited (widget);
+  screen = gdk_screen_get_default ();
+  composited = gdk_screen_is_composited (screen);
 
   gtk_widget_set_app_paintable (widget, composited);
 }
@@ -51,6 +55,7 @@ int
 main (int argc, char **argv)
 {
   GOptionContext *ctxt;
+  WnckHandle *handle;
   WnckScreen *screen;
   GtkWidget *win;
   GtkWidget *frame;
@@ -68,8 +73,10 @@ main (int argc, char **argv)
   if (rtl)
     gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL);
 
-  wnck_set_default_mini_icon_size (icon_size);
-  screen = wnck_screen_get_default ();
+
+  handle = wnck_handle_new (WNCK_CLIENT_TYPE_APPLICATION);
+  wnck_handle_set_default_mini_icon_size (handle, icon_size);
+  screen = wnck_handle_get_default_screen (handle);
 
   /* because the pager doesn't respond to signals at the moment */
   wnck_screen_force_update (screen);
@@ -87,7 +94,7 @@ main (int argc, char **argv)
                     G_CALLBACK (gtk_main_quit),
                     NULL);
 
-  tasklist = wnck_tasklist_new ();
+  tasklist = wnck_tasklist_new_with_handle (handle);
 
   wnck_tasklist_set_include_all_workspaces (WNCK_TASKLIST (tasklist), display_all);
   if (always_group)
@@ -100,6 +107,8 @@ main (int argc, char **argv)
     wnck_tasklist_set_grouping (WNCK_TASKLIST (tasklist),
                                 WNCK_TASKLIST_AUTO_GROUP);
 
+  wnck_tasklist_set_scroll_enabled (WNCK_TASKLIST (tasklist), enable_scroll);
+
   wnck_tasklist_set_middle_click_close (WNCK_TASKLIST (tasklist), TRUE);
 
   wnck_tasklist_set_orientation (WNCK_TASKLIST (tasklist),
@@ -155,5 +164,7 @@ main (int argc, char **argv)
 
   gtk_main ();
 
+  g_object_unref (handle);
+
   return 0;
 }
